@@ -28,6 +28,124 @@ LOG = logging.getLogger(__name__)
 
 
 class Changes(debian.deb822.Changes):
+    class Options(object):
+        """
+        Uploader options in changes.
+
+        >>> "{}".format(Changes("./examples/doctests/changes.options").options)
+        u"auto-ports=[u'jessie-test-unstable', u'squeeze-test-snasphot'], ignore-lintian=True, ignore-lintian[i386]=False, internal-apt-priority=543, run-lintian=True, run-lintian[i386]=False"
+
+        >>> "{}".format(Changes("./examples/doctests/changes.magic").options)
+        u"auto-ports=[u'jessie-test-unstable', u'squeeze-test-snasphot'], ignore-lintian=True"
+        """
+        class Bool(object):
+            _TRUE = ["true", "1"]
+            _FALSE = ["false", "0"]
+            _VALID = _TRUE + _FALSE
+
+            def __init__(self, raw_value):
+                if raw_value.lower() not in self._VALID:
+                    raise Exception("Bool value must be one of {}".format(",".join(self._VALID)))
+                self.value = raw_value.lower() in self._TRUE
+
+        class Int(object):
+            def __init__(self, raw_value):
+                self.value = int(raw_value)
+
+        class CSV(object):
+            def __init__(self, raw_value):
+                self.value = raw_value.split(",")
+
+        KEYWORD = "MINI_BUILDD_OPTION"
+        _OPTIONS = {"ignore-lintian": Bool,
+                    "run-lintian": Bool,
+                    "internal-apt-priority": Int,
+                    "auto-ports": CSV}
+
+        @classmethod
+        def _get_top_changes(cls, upload_changes):
+            """Filter only the first block from the changes (changelog) entry.
+
+            Upload changes may include multiple version blocks from
+            the changelog (internal porting does it, for example),
+            but we must only consider values from the top one.
+            """
+            result = ""
+            header_found = False
+            for line in upload_changes.get("Changes", "").splitlines(True):
+                if re.match(r"^ [a-z0-9]+", line):
+                    if header_found:
+                        break
+                    header_found = True
+                result += line
+            return result
+
+        def _compat_parse_magic(self):
+            """
+            Compat parse support for old style "magic" options.
+            """
+            def warning(magic, option):
+                LOG.warn("Deprecated \"magic\" option \"{m}\" found. Please use new-style option \"{o}\" instead (see user manual).".format(m=magic, o=option))
+
+            magic_auto_backports = re.search(r"\*\s*MINI_BUILDD:\s*AUTO_BACKPORTS:\s*([^*.\[\]]+)", self._top_changes)
+            if magic_auto_backports:
+                warning("AUTO_BACKPORTS", "auto-ports")
+                self._set("auto-ports", magic_auto_backports.group(1))
+
+            magic_backport_mode = re.search(r"\*\s*MINI_BUILDD:\s*BACKPORT_MODE", self._top_changes)
+            if magic_backport_mode:
+                warning("BACKPORT_MODE", "ignore-lintian")
+                self._set("ignore-lintian", "true")
+
+        def __init__(self, upload_changes):
+            self._top_changes = self._get_top_changes(upload_changes)
+            self._options = {}
+            matches = re.findall(r"\*\s*{keyword}:\s*([^*.]+)=([^*.]+)".format(keyword=self.KEYWORD), self._top_changes)
+            for m in matches:
+                self._set(m[0], m[1])
+
+            self._compat_parse_magic()
+
+        def __unicode__(self):
+            return ", ".join("{k}={v}".format(k=key, v=value) for key, value in sorted(self._options.items()))
+
+        def _set(self, key, raw_value):
+            base_key = key.partition("[")[0]
+            value = re.sub(r"\s+", "", raw_value)
+
+            # Validity check for key
+            if base_key not in self._OPTIONS.keys():
+                raise Exception("Unknown upload option: {k}.".format(k=key))
+
+            # Duplicity check
+            if key in self._options.keys():
+                raise Exception("Duplicate upload option: {k}.".format(k=key))
+
+            # Value conversion check
+            converted_value = None
+            try:
+                converted_value = self._OPTIONS[base_key](value)
+            except Exception as e:
+                raise Exception("Invalid upload option value: {k}=\"{v}\" ({e})".format(k=key, v=value, e=e))
+
+            self._options[key] = converted_value.value
+
+            LOG.debug("Upload option set: {k}=\"{v}\"".format(k=key, v=value))
+
+        def get(self, key, alt=None, default=None):
+            """
+            Get first existing option value in this order: key[a], key, default.
+            """
+            # Validity check for key
+            if key not in self._OPTIONS.keys():
+                raise Exception("Internal error: Upload Options: Unknown key used for get(): {k}.".format(k=key))
+
+            if alt:
+                m_key = "{k}[{a}]".format(k=key, a=alt)
+                if m_key in self._options:
+                    return self._options.get(m_key, default)
+            return self._options.get(key, default)
+
     # Extra mini-buildd changes file types we invent
     TYPE_DEFAULT = 0
     TYPE_BREQ = 1
@@ -53,6 +171,9 @@ class Changes(debian.deb822.Changes):
         # Instance might be produced from a temporary file, so we need to save the hash now.
         self._spool_hash = self._spool_hash_from_file()
 
+        super(Changes, self).__init__([] if self._new else open(file_path))
+
+        self._options = None
         if self.BUILDREQUEST_RE.match(self._file_name):
             self._type = self.TYPE_BREQ
         elif self.BUILDRESULT_RE.match(self._file_name):
@@ -60,7 +181,6 @@ class Changes(debian.deb822.Changes):
         else:
             self._type = self.TYPE_DEFAULT
 
-        super(Changes, self).__init__([] if self._new else open(file_path))
         # Be sure base dir is always available
         mini_buildd.misc.mkdirs(os.path.dirname(file_path))
 
@@ -76,6 +196,15 @@ class Changes(debian.deb822.Changes):
         else:
             return "User upload: {i}".format(i=self.get_pkg_id())
 
+    @property
+    def options(self):
+        """
+        .. note:: We can't parse this in constructor currently: Upload option error handling won't work properly, exceptions triggered too early in packager.py.
+        """
+        if not self._options:
+            self._options = self.Options(self)
+        return self._options
+
     @property
     def type(self):
         return self._type
@@ -164,34 +293,6 @@ class Changes(debian.deb822.Changes):
     def is_new(self):
         return self._new
 
-    def _magic_get_changes(self):
-        """
-        Filter only the first block from the changes (changelog) entry.
-
-        We need this for the 'magic' values only. Uploads may
-        include multiple blocks from the changelog (internal
-        porting does it, for example), but we must only consider
-        values from the top one.
-        """
-        result = ""
-        header_found = False
-        for line in self.get("Changes", "").splitlines(True):
-            if re.match(r"^ [a-z0-9]+", line):
-                if header_found:
-                    break
-                header_found = True
-            result += line
-        return result
-
-    @property
-    def magic_auto_backports(self):
-        mres = re.search(r"\*\s*MINI_BUILDD:\s*AUTO_BACKPORTS:\s*([^*.\[\]]+)", self._magic_get_changes())
-        return (re.sub(r"\s+", "", mres.group(1))).split(",") if mres else []
-
-    @property
-    def magic_backport_mode(self):
-        return bool(re.search(r"\*\s*MINI_BUILDD:\s*BACKPORT_MODE", self._magic_get_changes()))
-
     def get_spool_id(self):
         return "{type}-{hash}".format(type=self.TYPE2NAME[self._type], hash=self._spool_hash)
 
@@ -388,7 +489,7 @@ class Changes(debian.deb822.Changes):
 
                 # Generate sources.list et.al. to be used
                 mini_buildd.misc.open_utf8(os.path.join(path, "apt_sources.list"), "w").write(dist.mbd_get_apt_sources_list(repository, suite_option))
-                mini_buildd.misc.open_utf8(os.path.join(path, "apt_preferences"), "w").write(dist.mbd_get_apt_preferences(repository, suite_option))
+                mini_buildd.misc.open_utf8(os.path.join(path, "apt_preferences"), "w").write(dist.mbd_get_apt_preferences(repository, suite_option, self.options.get("internal-apt-priority")))
                 mini_buildd.misc.open_utf8(os.path.join(path, "apt_keys"), "w").write(repository.mbd_get_apt_keys(dist))
                 chroot_setup_script = os.path.join(path, "chroot_setup_script")
                 # Note: For some reason (python, django sqlite, browser?) the text field may be in DOS mode.
@@ -414,7 +515,7 @@ class Changes(debian.deb822.Changes):
                     breq["Arch-All"] = "Yes"
                 breq["Build-Dep-Resolver"] = dist.get_build_dep_resolver_display()
                 breq["Apt-Allow-Unauthenticated"] = "1" if dist.apt_allow_unauthenticated else "0"
-                if dist.lintian_mode != dist.LINTIAN_DISABLED:
+                if dist.lintian_mode != dist.LINTIAN_DISABLED and self.options.get("run-lintian", alt=ao.architecture.name, default=True):
                     # Generate lintian options
                     modeargs = {
                         dist.LINTIAN_DISABLED: "",
