@@ -289,17 +289,7 @@ codeversion is only used for base sources.""")
 
             AED4B06F473041FA: Debian Archive Automatic Signing Key (6.0/squeeze) <ftpmaster@debian.org>
             64481591B98321F9: Squeeze Stable Release Key <debian-release@lists.debian.org>
-
-            9AA38DCD55BE302B: Debian Archive Automatic Signing Key (5.0/lenny) <ftpmaster@debian.org>
-            4D270D06F42584E6: Lenny Stable Release Key <debian-release@lists.debian.org>
-
-            B5D0C804ADB11277: Etch Stable Release Key <debian-release@lists.debian.org>
-            EA8E8B2116BA136C: Backports.org Archive Key <ftp-master@backports.org>
             """
-            cls._mbd_get_or_create(msglog, "Debian", "etch",
-                                   ["9AA38DCD55BE302B", "B5D0C804ADB11277"])
-            cls._mbd_get_or_create(msglog, "Debian", "lenny",
-                                   ["AED4B06F473041FA", "4D270D06F42584E6"])
             cls._mbd_get_or_create(msglog, "Debian", "squeeze",
                                    ["AED4B06F473041FA", "64481591B98321F9"])
             cls._mbd_get_or_create(msglog, "Debian", "wheezy",
@@ -310,10 +300,6 @@ codeversion is only used for base sources.""")
                                    ["8B48AD6246925553", "7638D0442B90D010"])
             cls._mbd_get_or_create(msglog, "Debian", "sid",
                                    ["8B48AD6246925553", "6FB2A1C265FFB764", "7638D0442B90D010"])
-            cls._mbd_get_or_create(msglog, "Backports.org archive", "etch-backports",
-                                   ["EA8E8B2116BA136C"])
-            cls._mbd_get_or_create(msglog, "Debian Backports", "lenny-backports",
-                                   ["AED4B06F473041FA"])
             cls._mbd_get_or_create(msglog, "Debian Backports", "squeeze-backports",
                                    ["AED4B06F473041FA", "8B48AD6246925553"])
             cls._mbd_get_or_create(msglog, "Debian Backports", "wheezy-backports",
@@ -326,26 +312,6 @@ codeversion is only used for base sources.""")
         @classmethod
         def mbd_meta_add_ubuntu(cls, msglog):
             "Add well-known Ubuntu sources"
-            cls._mbd_get_or_create(msglog, "Ubuntu", "precise",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "precise-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: precise\nSuite: precise-backports")
-            cls._mbd_get_or_create(msglog, "Ubuntu", "quantal",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "quantal-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: quantal\nSuite: quantal-backports")
-            cls._mbd_get_or_create(msglog, "Ubuntu", "raring",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "raring-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: raring\nSuite: raring-backports")
-            cls._mbd_get_or_create(msglog, "Ubuntu", "saucy",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "saucy-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: saucy\nSuite: saucy-backports")
             cls._mbd_get_or_create(msglog, "Ubuntu", "trusty",
                                    ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
             cls._mbd_get_or_create(msglog, "Ubuntu", "trusty-backports",
@@ -371,6 +337,11 @@ codeversion is only used for base sources.""")
             cls._mbd_get_or_create(msglog, "Ubuntu", "xenial-backports",
                                    ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
                                    "Codename: xenial\nSuite: xenial-backports")
+            cls._mbd_get_or_create(msglog, "Ubuntu", "yakkety",
+                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
+            cls._mbd_get_or_create(msglog, "Ubuntu", "yakkety-backports",
+                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
+                                   "Codename: yakkety\nSuite: yakkety-backports")
 
         @classmethod
         def mbd_filter_active_base_sources(cls):
